#
# spec file for package dapl
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           dapl
Summary:        A Library for userspace access to RDMA devices using OS Agnostic DAT APIs
License:        BSD-3-Clause or GPL-2.0+ or CPL-1.0
Group:          Productivity/Networking/System
Version:        2.0.42
Release:        9.5
Source0:        https://www.openfabrics.org/downloads/dapl/dapl-%{version}.tar.gz
Source1:        baselibs.conf
Source2:        dapl-rpmlintrc
Patch1:         dapl-2.0.30-dat-ia-open-hang.patch
Patch4:         dapl-fix_type_punning.patch
Patch5:         dapl-define_NULL.patch
Patch6:         dapl-man_page_fixes.patch
Patch7:         dapl-fsf_address.patch
Patch8:         dapl-add-s390x-platform-support.patch
Patch9:         dapl-autotools.patch
Patch10:        dapl-rename_dtest.patch
Patch11:        dapl-add-aarch64-platform-support.patch
Url:            http://www.openfabrics.org
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libibverbs-devel
BuildRequires:  librdmacm-devel
BuildRequires:  libtool

%if "%name" == "dapl-debug"
Conflicts:      dapl
%endif

# bug437293
%ifarch ppc64
Obsoletes:      dapl-64bit
%endif
#
Requires(post):   /sbin/ldconfig
Requires(postun): /sbin/ldconfig
Requires(post):   sed
Requires(post):   coreutils

# libdapl*.so work like plugins, hence they do not get a separate subpackage.

%if "%{name}" == "dapl-debug"
%define lname       dapl-debug-libs
%define other_lname libdat2-2
%else
%define lname       libdat2-2
%define other_lname dapl-debug-libs
%endif

%description
Along with the OpenFabrics kernel drivers, libdat and libdapl provides
a userspace RDMA API that supports DAT 2.0 specification and IB
transport extensions for atomic operations and rdma write with
immediate data.

%package     -n %lname
Summary:        DAPL runtime libraries
Group:          System/Libraries
Conflicts:      %other_lname
Obsoletes:      dapl2 < %version
Provides:       dapl2 = %version
# Need dat.conf
Requires:       %name

%description -n %lname
Along with the OpenIB kernel drivers, libdat2 and libdapl provide a
userspace RDMA API that supports DAT 2.0 specification.

%description -n %lname
This package contains the runtime libraries.
%if "%{name}" == "dapl-debug"
The libraries have tracing enabled.
%endif

%package        devel
Summary:        Development files for the libdat and libdapl libraries
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       glibc-devel
%if "%{name}" == "dapl"
Conflicts:      dapl-debug-devel
%else
Provides:       dapl-devel
%endif

%description    devel
Library links and header files for the libdat and libdapl libraries.

%if "%{name}" != "dapl-debug"
%package        doc
Summary:        Manual pages for libdapl
Group:          Documentation/Man
Requires:       %{name} = %{version}
Provides:       dapl:%{_mandir}/man5/dat.conf.5.gz
Provides:       dapl_man

%description doc
Along with the OpenFabrics kernel drivers, libdat and libdapl provides
a userspace RDMA API that supports DAT 2.0 specification and IB
transport extensions for atomic operations and rdma write with
immediate data. This package provides the Documentation for the
library.
%endif

%package        utils
Summary:        Test suites for the uDAPL library
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}-%{release}
%if "%{name}" == "dapl"
Conflicts:      dapl-debug-utils
%endif

%description utils
Useful test suites to validate the uDAPL library APIs.

%prep
%setup -q -n dapl-%{version}
%patch1
%patch4
%patch5
%patch6
%patch7
%patch8 -p1
%patch9
%patch10
%patch11 -p1

%build
mv man/dtest.1 man/dpltest.1
%if %suse_version == 1110
export ac_cv_suse11=yes
%endif
autoreconf -fi
%if "%name" == "dapl"
%configure --disable-static --with-pic
%else
%configure --disable-static --with-pic --enable-debug 
%endif

make %{?_smp_mflags}

%check
export MALLOC_CHECK_=2
make check
unset MALLOC_CHECK_

%install
make DESTDIR=%{buildroot} install

rm -f %{buildroot}%_libdir/*.la
%if "%{name}" == "dapl-debug"
rm -rf %{buildroot}%{_mandir}/man{1,5}/* 
%endif
mkdir -p %{buildroot}%_sysconfdir
touch %{buildroot}%_sysconfdir/dat.conf

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%post
/sbin/ldconfig
if test -e %_sysconfdir/dat.conf; then
	sed -i -e '/ofa-v2-.* u2/d' %_sysconfdir/dat.conf
else
    touch %_sysconfdir/dat.conf
fi
cat <<EOF >>%_sysconfdir/dat.conf
ofa-v2-mlx4_0-1 u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx4_0 1" ""
ofa-v2-mlx4_0-2 u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx4_0 2" ""
ofa-v2-ib0 u2.0 nonthreadsafe default libdaplofa.so.2 dapl.2.0 "ib0 0" ""
ofa-v2-ib1 u2.0 nonthreadsafe default libdaplofa.so.2 dapl.2.0 "ib1 0" ""
ofa-v2-mthca0-1 u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mthca0 1" ""
ofa-v2-mthca0-2 u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mthca0 2" ""
ofa-v2-ipath0-1 u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "ipath0 1" ""
ofa-v2-ipath0-2 u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "ipath0 2" ""
ofa-v2-ehca0-2 u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "ehca0 1" ""
ofa-v2-iwarp u2.0 nonthreadsafe default libdaplofa.so.2 dapl.2.0 "eth2 0" ""
ofa-v2-mlx4_0-1u u2.0 nonthreadsafe default libdaploucm.so.2 dapl.2.0 "mlx4_0 1" ""
ofa-v2-mlx4_0-2u u2.0 nonthreadsafe default libdaploucm.so.2 dapl.2.0 "mlx4_0 2" ""
ofa-v2-mthca0-1u u2.0 nonthreadsafe default libdaploucm.so.2 dapl.2.0 "mthca0 1" ""
ofa-v2-mthca0-2u u2.0 nonthreadsafe default libdaploucm.so.2 dapl.2.0 "mthca0 2" ""
ofa-v2-cma-roe-eth2 u2.0 nonthreadsafe default libdaplofa.so.2 dapl.2.0 "eth2 0" ""
ofa-v2-cma-roe-eth3 u2.0 nonthreadsafe default libdaplofa.so.2 dapl.2.0 "eth3 0" ""
ofa-v2-scm-roe-mlx4_0-1 u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx4_0 1" ""
ofa-v2-scm-roe-mlx4_0-2 u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx4_0 2" ""
ofa-v2-mcm-1 u2.0 nonthreadsafe default libdaplomcm.so.2 dapl.2.0 "mlx4_0 1" ""
ofa-v2-mcm-2 u2.0 nonthreadsafe default libdaplomcm.so.2 dapl.2.0 "mlx4_0 2" ""
ofa-v2-scif0 u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "scif0 1" ""
ofa-v2-scif0-u u2.0 nonthreadsafe default libdaploucm.so.2 dapl.2.0 "scif0 1" ""
ofa-v2-mic0 u2.0 nonthreadsafe default libdaplofa.so.2 dapl.2.0 "mic0:ib 1" ""
ofa-v2-mlx4_0-1s u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx4_0 1" ""
ofa-v2-mlx4_0-2s u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx4_0 2" ""
ofa-v2-mlx4_1-1s u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx4_1 1" ""
ofa-v2-mlx4_1-2s u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx4_1 2" ""
ofa-v2-mlx4_1-1u u2.0 nonthreadsafe default libdaploucm.so.2 dapl.2.0 "mlx4_1 1" ""
ofa-v2-mlx4_1-2u u2.0 nonthreadsafe default libdaploucm.so.2 dapl.2.0 "mlx4_1 2" ""
ofa-v2-mlx4_0-1m u2.0 nonthreadsafe default libdaplomcm.so.2 dapl.2.0 "mlx4_0 1" ""
ofa-v2-mlx4_0-2m u2.0 nonthreadsafe default libdaplomcm.so.2 dapl.2.0 "mlx4_0 2" ""
ofa-v2-mlx4_1-1m u2.0 nonthreadsafe default libdaplomcm.so.2 dapl.2.0 "mlx4_1 1" ""
ofa-v2-mlx4_1-2m u2.0 nonthreadsafe default libdaplomcm.so.2 dapl.2.0 "mlx4_1 2" ""
ofa-v2-mlx5_0-1s u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx5_0 1" ""
ofa-v2-mlx5_0-2s u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx5_0 2" ""
ofa-v2-mlx5_1-1s u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx5_1 1" ""
ofa-v2-mlx5_1-2s u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx5_1 2" ""
ofa-v2-mlx5_0-1u u2.0 nonthreadsafe default libdaploucm.so.2 dapl.2.0 "mlx5_0 1" ""
ofa-v2-mlx5_0-2u u2.0 nonthreadsafe default libdaploucm.so.2 dapl.2.0 "mlx5_0 2" ""
ofa-v2-mlx5_1-1u u2.0 nonthreadsafe default libdaploucm.so.2 dapl.2.0 "mlx5_1 1" ""
ofa-v2-mlx5_1-2u u2.0 nonthreadsafe default libdaploucm.so.2 dapl.2.0 "mlx5_1 2" ""
ofa-v2-mlx5_0-1m u2.0 nonthreadsafe default libdaplomcm.so.2 dapl.2.0 "mlx5_0 1" ""
ofa-v2-mlx5_0-2m u2.0 nonthreadsafe default libdaplomcm.so.2 dapl.2.0 "mlx5_0 2" ""
ofa-v2-mlx5_1-1m u2.0 nonthreadsafe default libdaplomcm.so.2 dapl.2.0 "mlx5_1 1" ""
ofa-v2-mlx5_1-2m u2.0 nonthreadsafe default libdaplomcm.so.2 dapl.2.0 "mlx5_1 2" ""
EOF
#On update save configuration before uninstall of old package runs
if [ $1 -gt 0 ]; then
	cp -p %_sysconfdir/dat.conf %_sysconfdir/dat.conf.rpmtmp
fi

%posttrans
if [ -e "%_sysconfdir/dat.conf.rpmtmp" ]; then
  mv %_sysconfdir/dat.conf.rpmtmp %_sysconfdir/dat.conf
fi

%postun
/sbin/ldconfig
#remove if this isn't an update
if [ $1 -eq 0 ]; then
	if test -e %_sysconfdir/dat.conf; then
		sed -i -e '/OpenIB-.* u1/d' %_sysconfdir/dat.conf
	fi
fi

%files
%defattr(-, root, root)
%doc AUTHORS README COPYING ChangeLog LICENSE.txt LICENSE2.txt LICENSE3.txt
%_libdir/libdapl*.so.*
%config %ghost %_sysconfdir/dat.conf

%files -n %lname
%defattr(-,root,root)
%_libdir/libdat2.so.*

%files devel
%defattr(-, root, root)
%_includedir/dat2/
%_libdir/*.so

%if "%{name}" != "dapl-debug"
%files doc
%defattr(-, root, root)
%_mandir/man1/*
%_mandir/man5/*
%endif

%files utils
%defattr(-,root,root,-)
%{_bindir}/*

%changelog
* Thu Sep 10 2015 dmueller@suse.com
- add dapl-add-aarch64-platform-support.patch (fate#318444)
- revert last change
* Tue Aug 25 2015 pth@suse.de
- Exclude aarch64 as there is currently no assembler code for this
  architecture.
* Tue Aug 11 2015 pth@suse.de
- Replace dapl-s390_support.patch with
  dapl-add-s390x-platform-support.patch (bsc#934683).
* Wed Feb  4 2015 dimstar@opensuse.org
- Also have dapl-utils conflict with dapl-debug-utils.
- Fix baselibs.conf to build libdat2-2-32bit.
* Mon Sep  8 2014 coolo@suse.com
- dapl-debug can't obsolete dapl or zypper will switch between the versions
  all the time. They do conflict though
* Fri Aug  8 2014 pth@suse.de
- Add dapl-rename_dtest.patch to rename dtest to dpltest because
  of name clash with dateutils.
- Also rename the man  page for dtest.
- Make dapl-devel and dapl-debug-devel obsolete each other.
* Fri Jun 27 2014 pth@suse.de
- Add baselibs.conf and dapl-rpmlintrc as source.
- Fix type punning in cm.c
* Wed Jun 25 2014 pth@suse.de
- Remove dapl-2.0.13-build_error.patch as it isn't needed anymore.
* Wed Jun 25 2014 pth@suse.de
- Provide fuill source URL
* Thu Feb 13 2014 pth@suse.de
- Update to 2.0.40 (fate#315488):
    dist: ib collective extension include files missing
    dapltest: the quit command is missing changes for -n option.
    Server-port was not being set properly during param init phase
    on the client side.
    dat.conf: remove v1, add Mellanox Connect-IB and Intel Xeon Phi
    MIC.
    NULL undefined on Fedora, incorrectly using kernel stddef.h
* Tue Jan 21 2014 pth@suse.de
- Add dapl-autotools.patch to make autoreconf complain less.
* Fri Jan 17 2014 pth@suse.de
- Update to 2.0.39 from 3.12 daily snapshot.
- Include dapl-s390_support.patch from IBM for s390 support.
- Remove now unneeded patches:
  dapl-2.0.13-build_error.patch
- Use script to generate spec and changes for dapl-debug from the
  dapl files.
* Wed Jan 15 2014 pth@suse.de
- Build for s390x
* Thu Sep 13 2012 pth@suse.de
- Add another filter to dapl-rpmlintrc as the packages for
  the runtime library are named differently but contain a library
  that's named the same.
* Wed Sep  5 2012 pth@suse.de
- Reinstate the arch exclusion of s390(x).
- Recompress with bzip2.
* Wed Sep  5 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Remove unjustified s390* arch exclusion
- Implement shared library policy
* Thu Aug 30 2012 pth@suse.de
- Update to OFED 1.5.4.1 (dapl unchanged).
- Rename the package with tracing enabled dapl-tracing.
- Adapt baselibs.conf to new packages and names.
- Use one .spec and .changes file and create the -tracing
  variants with pre_checkin.sh.
- Update FSF address in LICENSE3.txt.
* Tue Jul  3 2012 pth@suse.de
- Put shared libs into a versioned package.
- Fix man pages
- Add a rpmlintrc to shut up warnings that can only be solved upstream.
* Thu Jun 28 2012 pth@suse.de
- Use unions for type punning (dapl-type_punning.patch).
- Include stddef.h to get NULL defined.
- Require automake, autoconf and libtool.
- Provide obsoleted items.
* Wed May  9 2012 pth@suse.de
- Update to OFED 1.5.4
- Don't recompress the tarball.
- Remove unneeded patches and adapt the remaining ones.
* Mon Jun 20 2011 pth@suse.de
- Sed is also needed.
* Thu Jun  9 2011 pth@suse.de
- After last change dapl needs cat so add prereq (bnc#688511).
* Mon Mar  7 2011 pth@suse.de
- Don't remove the configuration for this dapl version on update
  (bnc#676731).
- Use cat instead of multiple echos.
- Include /etc/dat.conf as %%conf %%ghost.
* Fri Mar  4 2011 pth@suse.de
- Fix tmp race in post/postun (bnc#676700).
* Tue Feb  1 2011 pth@suse.de
- Incorporate fixes done for the update in SLE10:
- Split off man pages into their own sub package that can be
  required by compat-dapl.
- Fix type-punning in test app so that we don't need
  - fno-strict-aliasing allowing better code optimisation.
- Also fix type punning in other files that the newer gcc in SLE11
  detected.
- realigned-disconnect.patch fixing bnc#656702
- added cma-fix-debug-build-issue.patch fixing debug build.
* Tue Nov 23 2010 pth@suse.de
- Let the caller detect EINTR (bnc#655518).
* Mon Oct 25 2010 jjolly@novell.com
- Update to v2.0.30 from OFED 1.5.2
- Update to include more lines for dat.conf
- Patch to remove extra rdma_destroy_id() (bnc#647915)
* Tue Dec  8 2009 ro@suse.de
- fix build on ia64: help configure dectecting suse_version
* Thu Dec  3 2009 jjolly@suse.de
- Update to v2.0.19 from OFED 1.4.2
* Thu Dec 11 2008 jjolly@suse.de
- Updated to v2.0.15 from OFED 1.4 GA
  - dapltest: transaction test moves to cleanup stage before
    rdma_read processing is complete
  - Change SR to include sysconfdir.
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Nov  6 2008 ihno@suse.de
- adding baselibs.conf
* Tue Nov  4 2008 ro@suse.de
- fix build on ia64 (same as in compat-dapl)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Mon Oct 27 2008 jjolly@suse.de
- Updated to v2.0.14 from OFED 1.4 rc3
* Mon Oct 20 2008 ihno@suse.de
- Excludearch for s390 s390x
* Fri Sep 12 2008 jjolly@suse.de
- Updated to v2.0.13 from OFED 1.4 RC1 and changed from dapl2 to dapl
* Mon Apr 28 2008 crrodriguez@suse.de
- do not build unusable static libraries
- fix -devel package requires
* Mon Mar  3 2008 jjolly@suse.de
- Initial submission of dapl v2.0.7 from OFED 1.3 GA release
